<?php
/**
 * Banner Seven Widget
 */

namespace Elementor;
class Cyarb_Banner_Seven extends Widget_Base {

	public function get_name() {
        return 'Cyarb_BannerSeven';
    }

	public function get_title() {
        return __( 'Banner Seven', 'cyarb-toolkit' );
    }

	public function get_icon() {
        return 'eicon-banner';
    }

	public function get_categories() {
        return [ 'cyarb-elements' ];
    }

	protected function register_controls() {

        $this->start_controls_section(
			'Cyarb_Banner_Area',
			[
				'label' => __( 'Banner Seven', 'cyarb-toolkit' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_control(
            'title_type',
            [
                'label'       => __( 'Choose Heading Type', 'cyarb-toolkit' ),
                'type'        => Controls_Manager::SELECT,
                'label_block' => true,
                'options'     => [
                    'h1' => __( 'h1', 'cyarb-toolkit' ),
                    'h2' => __( 'h2', 'cyarb-toolkit' ),
                    'h3' => __( 'h3', 'cyarb-toolkit' ),
                    'h4' => __( 'h4', 'cyarb-toolkit' ),
                    'h5' => __( 'h5', 'cyarb-toolkit' ),
                    'h6' => __( 'h6', 'cyarb-toolkit' ),
                ], 
                'default' => 'h1'
            ]
        );

        $this->add_control(
            'add_image',
            [
                'label'   => __('Add Banner Image', 'cyarb-toolkit' ),
                'type'    => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ]
            ]
        );
        $this->add_control(
            'top_title', [
                'label' => __( 'Top Title', 'cyarb-toolkit' ),
                'type'  => Controls_Manager:: TEXT,
            ]
		);
        $this->add_control(
            'banner_title', [
                'label' => __( 'Add Banner Title', 'cyarb-toolkit' ),
                'type'  => Controls_Manager:: TEXTAREA,
            ]
		);
        $this->add_control(
            'banner_desc',
            [
                'label'       =>__('Banner Description', 'cyarb-toolkit'),
                'type'        => Controls_Manager:: WYSIWYG,
                'description' => __('This text editor for p','cyarb-toolkit'),
            ]
		);
        $this->add_control(
            'btn_text1',
            [
                'label' => esc_html__('Button One Title', 'cyarb-toolkit'),
                'type'  => Controls_Manager:: TEXT,
            ]
        );
        $this->add_control(
            'link_type',
            [
                'label' => esc_html__( 'Link Type', 'cyarb-toolkit' ),
                'type'  => Controls_Manager::SELECT,
                'label_block' => true,
                'options' => [
                    '1'  => esc_html__( 'Link To Page', 'cyarb-toolkit' ),
                    '2'  => esc_html__( 'External Link', 'cyarb-toolkit' ),
                ],
            ]
        );
        $this->add_control(
            'link_to_page',
            [
                'label'       => esc_html__( 'Link Page', 'cyarb-toolkit' ),
                'type'        => Controls_Manager::SELECT,
                'label_block' => true,
                'options'     => cyarb_toolkit_get_page_as_list(),
                'condition'   => [
                    'link_type' => '1',
                ]
            ]
        );
        $this->add_control(
            'external_link',
            [
                'label'     => esc_html__('External Link', 'cyarb-toolkit'),
                'type'      => Controls_Manager:: TEXT,
                'condition' => [
                    'link_type' => '2',
                ]
            ]
        );
        // Button Two
        $this->add_control(
            'btn_text2',
            [
                'label' => esc_html__('Button Two Title', 'cyarb-toolkit'),
                'type'  => Controls_Manager:: TEXT,
            ]
        );
        $this->add_control(
            'link_type2',
            [
                'label' => esc_html__( 'Link Type 2', 'cyarb-toolkit' ),
                'type'  => Controls_Manager::SELECT,
                'label_block' => true,
                'options' => [
                    '1'  => esc_html__( 'Link To Page', 'cyarb-toolkit' ),
                    '2' => esc_html__( 'External Link', 'cyarb-toolkit' ),
                ],
            ]
        );
        $this->add_control(
            'link_to_page2',
            [
                'label'       => esc_html__( 'Link Page', 'cyarb-toolkit' ),
                'type'        => Controls_Manager::SELECT,
                'label_block' => true,
                'options'     => cyarb_toolkit_get_page_as_list(),
                'condition'   => [
                    'link_type2' => '1',
                ]
            ]
        );
        $this->add_control(
            'external_link2',
            [
                'label'     => esc_html__('External Link', 'cyarb-toolkit'),
                'type'      => Controls_Manager:: TEXT,
                'condition' => [
                    'link_type2' => '2',
                ]
            ]
        );
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Style', 'cyarb-toolkit' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
            $this->add_control(
                'banner_top_t_color',
                [
                    'label'     => esc_html__( 'Top Title Color', 'cyarb-toolkit' ),
                    'type'      => Controls_Manager::HEADING,
                    'separator' => 'before',
                ]
            );
            $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name' => 'top_title_color',
                    'label' => esc_html__( 'Top Title Color', 'cyarb-toolkit' ),
                    'types' => ['gradient' ],
                    'selector' => '{{WRAPPER}} .new-main-banner-black-content .sub-title',
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'top_title_typography',
                    'label' => __( 'Top Title Typography', 'cyarb-toolkit' ),
                    'selector' => '{{WRAPPER}} .new-main-banner-black-content .sub-title',
                ]
            );
            $this->add_control(
                'top_td',
                [
                    'type'      => Controls_Manager::DIVIDER,
                ]
            );
            
            $this->add_control(
                'title_color',
                [
                    'label'     => __( 'Title Color', 'cyarb-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .new-main-banner-black-content h1, .new-main-banner-black-content h2, .new-main-banner-black-content h3, .new-main-banner-black-content h4, .new-main-banner-black-content h5, .new-main-banner-black-content h6' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'title_type_typography',
                    'label'    => __( 'Title Typography', 'cyarb-toolkit' ),
                    'selector' => '{{WRAPPER}} .new-main-banner-black-content h1, .new-main-banner-black-content h2, .new-main-banner-black-content h3, .new-main-banner-black-content h4, .new-main-banner-black-content h5, .new-main-banner-black-content h6',
                ]
            );
            
            $this->add_control(
                'content_color',
                [
                    'label'     => __( 'Content Color', 'cyarb-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .new-main-banner-black-content p' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'content_type_typography',
                    'label'    => __( 'Content Type Typography', 'cyarb-toolkit' ),
                    'selector' => '{{WRAPPER}} .new-main-banner-black-content p',
                ]
            );
            $this->add_control(
                'btn_color',
                [
                    'label'     => __( 'Button One Color', 'cyarb-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .default-btn-two' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_control(
                'btn_hcolor',
                [
                    'label'     => __( 'Button One Hover Color', 'cyarb-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .default-btn-two:hover' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'btn_type_typography',
                    'label'    => __( 'Button One Typography', 'cyarb-toolkit' ),
                    'selector' => '{{WRAPPER}} .default-btn',
                ]
            );
            $this->add_control(
                'btn2_color',
                [
                    'label'     => __( 'Button Two Color', 'cyarb-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .optional-btn' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_control(
                'btn2_hcolor',
                [
                    'label'     => __( 'Button Two Hover Color', 'cyarb-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .optional-btn:hover' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_control(
                'btn2_bordercolor',
                [
                    'label'     => __( 'Button Two Border Color', 'cyarb-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .optional-btn' => 'border-color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'btn2_type_typography',
                    'label' => __( 'Button Two Typography', 'cyarb-toolkit' ),
                    'selector' => '{{WRAPPER}} .optional-btn',
                ]
            );

            $this->add_control(
                'btn1_bg_color',
                [
                    'label'     => esc_html__( 'Button One Background Color', 'cyarb-toolkit' ),
                    'type'      => Controls_Manager::HEADING,
                    'separator' => 'before',
                ]
            );
            $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name'     => 'btn1_bg_color',
                    'types'    => ['gradient' ],
                    'selector' => '{{WRAPPER}} .default-btn-two',
                ]
            ); 
            $this->add_control(
				'btn1divider',
				[
					'type' => Controls_Manager::DIVIDER,
				]
			);
            $this->add_control(
                'btn1_bg_hcolor',
                [
                    'label'     => esc_html__( 'Button One Background Hover Color', 'cyarb-toolkit' ),
                    'type'      => Controls_Manager::HEADING,
                    'separator' => 'before',
                ]
            );
            $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name'     => 'btn1_bg_hcolor',
                    'types'    => ['gradient' ],
                    'selector' => '{{WRAPPER}} .default-btn-two:hover, .default-btn-two::before',
                ]
            ); 
            $this->add_control(
				'btn2divider',
				[
					'type' => Controls_Manager::DIVIDER,
				]
			);
            $this->add_control(
                'btn2_bg_hcolor',
                [
                    'label'     => esc_html__( 'Button Two Background Hover Color', 'cyarb-toolkit' ),
                    'type'      => Controls_Manager::HEADING,
                    'separator' => 'before',
                ]
            );
            $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name'     => 'btn2_bg_hcolor',
                    'types'    => ['gradient' ],
                    'selector' => '{{WRAPPER}} .new-main-banner-wrap-slides-content .banner-btn-box li .optional-btn::before',
                ]
            ); 
        $this->end_controls_section();

    }

	protected function render() {

		$settings = $this->get_settings_for_display(); 
        
        $link_one = '';
        if($settings['link_type'] == 1){
            $link_one = get_page_link($settings['link_to_page']); 
        } else {
            $link_one = $settings['external_link'];
        }
        
        $link_two = '';
        if($settings['link_type2'] == 1){
            $link_two = get_page_link($settings['link_to_page2']); 
        } else {
            $link_two = $settings['external_link2'];
        }
        ?>

        <div class="new-main-banner-black-area">
            <div class="container-fluid">
                <div class="new-main-banner-black-content">
                    <?php if($settings['top_title'] != ''): ?>
                    <span class="sub-title"><?php echo esc_html( $settings['top_title'] ); ?></span>
                    <?php endif; ?>

                    <<?php echo esc_attr($settings['title_type']);?>><?php echo esc_html( $settings['banner_title'] ); ?></<?php echo esc_attr($settings['title_type']);?>>
                    <p><?php echo wp_kses_post( $settings['banner_desc'] ); ?></p>

                    <?php if( $settings['btn_text1'] != '' || $settings['btn_text2'] != '' ): ?>
                        <ul class="banner-btn-box">
                            <?php if( $settings['btn_text1'] != '' ): ?>
                            <li>
                                <a href="<?php echo esc_url( $link_one ); ?>" class="default-btn-two"><?php echo esc_html( $settings['btn_text1'] ) ?></a>
                            </li>
                            <?php endif; ?>

                            <?php if( $settings['btn_text2'] != '' ): ?>
                            <li>
                                <a href="<?php echo esc_url( $link_two ); ?>" class="optional-btn"><?php echo esc_html( $settings['btn_text2'] ) ?></a>
                            </li>
                            <?php endif; ?>
                        </ul>
                    <?php endif; ?>
                </div>
            </div>

            <?php if( $settings['add_image']['url'] != '') : ?>
                <div class="new-main-banner-black-image">
                    <img src="<?php echo esc_url( $settings['add_image']['url'] ); ?>" alt="<?php echo esc_attr('image','cyarb-toolkit'); ?>">
                </div>
            <?php endif; ?>
        </div>
        <?php
	}

}

Plugin::instance()->widgets_manager->register_widget_type( new Cyarb_Banner_Seven );